@@ -38,15 +38,16 @@ export class VideoPlayer extends Component {
 		this._onChange = this._onChange.bind(this);
 	}
 
-	getPreviewForSecond(source, forSecond = 0) {
+	getPreviewForSecond(source, forSecond = 0, maximumSize) {
 		const actualSource = getActualSource(source);
 		return new Promise((resolve, reject) => {
-			RNVideoTrimmer.getPreviewImageAtPosition(actualSource, forSecond, (err, base64) => {
-				if (err) {
-					return reject(err);
-				}
-				return resolve(base64);
-			});
+			RNVideoTrimmer.getPreviewImageAtPosition(actualSource, forSecond, maximumSize,
+				(err, base64) => {
+					if (err) {
+						return reject(err);
+					}
+					return resolve(base64);
+				});
 		});
 	}
 
